Structs
- Process
LogLookup Driver - Hostcall driver that fetches the logging channel for a running process.
- Process
Register LogDriver - Hostcall driver that records the logging channel exported by a process.
- Process
Start Driver - Hostcall driver that starts new processes.
- Process
Stop Driver - Hostcall driver that stops running processes.
Traits
- Entrypoint
Invocation Ext - Helpers for working with entrypoint invocations inside the kernel.
- Process
Lifecycle Capability - Capability responsible for starting/stopping guest instances.
Functions
- lifecycle_
ops - Build hostcall operations for process lifecycle management.
- log_ops
- Build hostcall operations for process log channel metadata.