Module operation

Module operation 

Structs

Operation
An asynchronous system task that a guest can execute in a non-blocking fashion.

Traits

Contract
Contract is used by kernel drivers to define a consistent method for guest execution. This allows Operations to expose the driver contract to the guest without having to know its internal structure.
LinkableOperation
Trait object for operations that can be linked into a Wasmtime linker.