pub enum RegistryError {
CapacityExhausted,
LockPoisoned,
InvalidReservation,
MissingInstance,
}Expand description
Errors surfaced when interacting with the registry.
Variants
CapacityExhausted
Registry has reached capacity and cannot accept more entries.
LockPoisoned
Registry state is unavailable because an internal lock is poisoned.
InvalidReservation
Attempted to initialise or access an invalid reservation.
MissingInstance
Instance state is missing from the registry.