Module process

Module process 

Structs

ProcessLogLookupDriver
Hostcall driver that fetches the logging channel for a running process.
ProcessRegisterLogDriver
Hostcall driver that records the logging channel exported by a process.
ProcessStartDriver
Hostcall driver that starts new processes.
ProcessStopDriver
Hostcall driver that stops running processes.

Traits

EntrypointInvocationExt
Helpers for working with entrypoint invocations inside the kernel.
ProcessLifecycleCapability
Capability responsible for starting/stopping guest instances.

Functions

lifecycle_ops
Build hostcall operations for process lifecycle management.
log_ops
Build hostcall operations for process log channel metadata.