Structs
- Operation
- An asynchronous system task that a guest can execute in a non-blocking fashion.
Traits
- Contract
Contractis used by kernel drivers to define a consistent method for guest execution. This allowsOperations to expose the driver contract to the guest without having to know its internal structure.- Linkable
Operation - Trait object for operations that can be linked into a Wasmtime linker.