pub struct Session { /* private fields */ }Implementations
Sourceimpl Session
impl Session
Sourcepub fn bootstrap(entitlements: Vec<Capability>, pubkey: [u8; 32]) -> Self
pub fn bootstrap(entitlements: Vec<Capability>, pubkey: [u8; 32]) -> Self
This is a highly privileged kernel function and should only be used by the
runtime to bootstrap the first guest session. This should never be exposed to
the userland. For userland session creation, use Self::create instead.
Note that we don’t accept any entitlement resource restrictions as they won’t yet exist. Best practice is to send every capability enabled in the current kernel.
Sourcepub fn create(
&self,
entitlements: HashMap<Capability, ResourceScope>,
pubkey: [u8; 32],
) -> Result<Self, SessionError>
pub fn create( &self, entitlements: HashMap<Capability, ResourceScope>, pubkey: [u8; 32], ) -> Result<Self, SessionError>
Create a new session, which will be linked to this one. Note that a session cannot create a new session with privileges beyond its own.
Note that sessions are mutable, so the privileges rule is only valid at creation time. It is perfectly possible (and valid) for a session to have its scope reduced subsequently, making the owning session less than the child session.
Sourcepub fn authenticate(&self, _payload: &[u8], _signature: &[u8]) -> bool
pub fn authenticate(&self, _payload: &[u8], _signature: &[u8]) -> bool
Authenticate a payload against this session’s public key. If successful, the payload is an authentic payload for this session and can be trusted. Otherwise this payload is counterfit, meaning either that one or both of session Id and request payload have been forged.
Authorise the requested action against the set of entitlements for this session. If successful, the action can safely be executed for the given resource. Otherwise the action is outside the permission scope and should not be executed.